:orphan:

.. title:: Matplotlib documentation

.. module:: matplotlib


##################################
Matplotlib |release| documentation
##################################

Matplotlib is a comprehensive library for creating static, animated,
and interactive visualizations in Python.

************
Installation
************

.. grid:: 1 1 2 2

    .. grid-item::

        Install using `pip <https://pypi.org/project/matplotlib>`__:

        .. code-block:: bash

            pip install matplotlib

    .. grid-item::

        Install using `conda <https://docs.continuum.io/anaconda/>`__:

        .. code-block:: bash

            conda install -c conda-forge matplotlib

Further details are available in the :doc:`Installation Guide <users/installing/index>`.


******************
Learning resources
******************

.. grid:: 1 1 2 2

    .. grid-item-card::
        :padding: 2

        Tutorials
        ^^^

        - :doc:`Quick-start guide <tutorials/introductory/quick_start>`
        - :doc:`Plot types <plot_types/index>`
        - :ref:`Introductory tutorials <tutorials-introductory>`
        - :doc:`External learning resources <users/resources/index>`

    .. grid-item-card::
        :padding: 2

        How-tos
        ^^^

        - :doc:`Example gallery <gallery/index>`
        - :doc:`Matplotlib FAQ <users/faq/index>`

    .. grid-item-card::
        :padding: 2

        Understand how Matplotlib works
        ^^^

        - The :ref:`users-guide-explain` in the :doc:`Users guide
          <users/index>`
        - Many of the :ref:`Intermediate <tutorials-intermediate>` and
          :ref:`Advanced <tutorials-advanced>` tutorials have explanatory
          material

    .. grid-item-card::
        :padding: 2

        Reference
        ^^^

        - :doc:`API Reference <api/index>`
        - :doc:`Axes API <api/axes_api>` for most plotting methods
        - :doc:`Figure API <api/figure_api>` for figure-level methods
        - Top-level interfaces to create:

          - Figures (`.pyplot.figure`)
          - Subplots (`.pyplot.subplots`, `.pyplot.subplot_mosaic`)


********************
Third-party packages
********************

There are many `Third-party packages
<https://matplotlib.org/mpl-third-party/>`_ built on top of and extending
Matplotlib.


************
Contributing
************

Matplotlib is a community project maintained for and by its users.  There are many ways
you can help!

- Help other users `on discourse <https://discourse.matplotlib.org>`__
- report a bug or request a feature `on GitHub <https://github.com/matplotlib/matplotlib/issues>`__
- or improve the :ref:`documentation and code <developers-guide-index>`
